@@ -1,4 +1,4 @@
-from dbconf import dbs
+from dbs import dbs
 import os
 
 from postgres import postgres
