@@ -97,7 +97,7 @@ def pipeable():
       """anonymous runner"""
 
     _run = runStuff(**queries[proj][querytorun].__dict__)
-    lines = _run.query(sys.argv[2:])
+    lines = _run.query(params)
     if len(lines) > 0:
       print "\n".join(lines)
     _run.storeResult("\n".join(lines))
